********************************************************************************
*
* This code run the regressions in the paper "Intergenerational Transmission of 
* Fertility: Evidence from China's Population Control Policies".
*
* Data: Data_Main_JoDE.dta
*
* Note. In the main regressions, (1) the wife's age-12 province FE is controlled
* for, (2) the wife's age-12 hukou status is used when defining rural/urban 
* residence type, (3) the wife's age-12 province is used when defining 
* high-and-low-income province, (4) the wife's sample weights are used, and (5)
* standard errors are clustered at the wife's birth year - female age-12 province
* level.
*
* Yongkun Yin, 2024-07-04.
*
********************************************************************************


* install the packages in need.
* ssc install estout, replace
* ssc install ivreg2, replace


clear

** set directory
* main folder
global mainPath "E:/Dropbox/IGTF Replication"

* Stata fo files folder
global doPath "$mainPath/Stata Files"

* original data folder
global dataPath "$mainPath/Data"

* results folder
global resultsPath "$mainPath/Results"


use "$dataPath/Data_Main_JoDE.dta", clear

cd "$dataPath/Results"


tab age_hus, gen(iage_hus)
tab age_wife, gen(iage_wife)

tab prov_12, gen(iprov_12_hus)
tab prov_12_wife, gen(iprov_12_wife)

egen cluster_group = group(prov_12_wife age_wife)


********************************************************************************

** Table A1. Sample restriction

gen sample0 = 1 if children_wife!=. & sib_hus!=. & sib_wife!=. & age_hus!=. & age_wife!=. & prov_12_wife!=.

gen sample1 = 1 if children_wife!=. & sib_hus!=. & sib_wife!=. & age_hus!=. & age_wife!=. & prov_12_wife!=. & age_wife>15 & age_wife<=46

gen sample2 = 1 if children_wife!=. & sib_hus!=. & sib_wife!=. & age_hus!=. & age_wife!=. & prov_12_wife!=. & age_wife>15 & age_wife<=46 & mbirthy_hus>=1920 & mbirthy_wife>=1920 & mbirthy_hus<1964 & mbirthy_wife<1964

gen sample3 = 1 if children_wife!=. & sib_hus!=. & sib_wife!=. & age_hus!=. & age_wife!=. & prov_12_wife!=. & age_wife>15 & age_wife<=46 & mbirthy_hus>=1920 & mbirthy_wife>=1920 & mbirthy_hus<1964 & mbirthy_wife<1964 & marriage_first_hus==1 & marriage_first_wife==1


est clear

eststo sum0: estpost tabstat children_wife sib_hus sib_wife sib_total ideal_children_hus ideal_children_wife exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife yr_school_hus yr_school_wife birth_quota minority age_hus age_wife urban_hukou_12_wife if sample0==1 [aw = rswt_nat_wife], c(stat) stat(n mean)

eststo sum1: estpost tabstat children_wife sib_hus sib_wife sib_total ideal_children_hus ideal_children_wife exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife yr_school_hus yr_school_wife birth_quota minority age_hus age_wife urban_hukou_12_wife if sample1==1 [aw = rswt_nat_wife], c(stat) stat(n mean)

eststo sum2: estpost tabstat children_wife sib_hus sib_wife sib_total ideal_children_hus ideal_children_wife exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife yr_school_hus yr_school_wife birth_quota minority age_hus age_wife urban_hukou_12_wife if sample2==1 [aw = rswt_nat_wife], c(stat) stat(n mean)

eststo sum3: estpost tabstat children_wife sib_hus sib_wife sib_total ideal_children_hus ideal_children_wife exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife yr_school_hus yr_school_wife birth_quota minority age_hus age_wife urban_hukou_12_wife if sample3==1 [aw = rswt_nat_wife], c(stat) stat(n mean)

esttab sum0 sum1 sum2 sum3 using "Table_sample.tex", replace cells( ( count mean(fmt(%6.3fc)) ) ) nonumber nomtitle nonote noobs label booktabs


** Table A2. Summary statistics

est clear

estpost tabstat children_wife sib_hus sib_wife sib_total ideal_children_hus ideal_children_wife exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife yr_school_hus yr_school_wife birth_quota minority age_hus age_wife urban_hukou_12_wife if sample3==1 [aw = rswt_nat_wife], c(stat) stat(n mean sd min max)

esttab using "Table_sum.tex", replace cells("count mean(fmt(%6.3fc)) sd(fmt(%6.3fc)) min max") nonumber nomtitle nonote noobs label booktabs collabels("Obs." "Mean" "Std. Dev." "Min." "Max.")


********************************************************************************

** Table 2. Effect of the number of siblings on the number of children

* OLS

est clear

ivreg2 children_wife sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2
 
ivreg2 children_wife sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

* 2SLS

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_kids_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_kids_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)


********************************************************************************

** Table 2. First-stage results

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group) first savefirst

est restore _ivreg2_sib_hus

outreg2 using Table_1st_stage_fw.tex, replace keep(exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) label

est restore _ivreg2_sib_wife

outreg2 using Table_1st_stage_fw.tex, append keep(exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) label

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group) first savefirst

est restore _ivreg2_sib_total

outreg2 esttab using Table_1st_stage_fw.tex, append keep(exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) label

/*

** run this block to see R^2
* Be careful: standard errors from the following regressions are not correct.

ivreg2 sib_hus exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

ivreg2 sib_wife exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

ivreg2 sib_total exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

*/


********************************************************************************

** Table 3. Effect of the number of siblings on violation of the OCP

* OLS

est clear

ivreg2 out_of_quota_child sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 out_of_quota_child sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2
 
ivreg2 out_of_quota_child sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 out_of_quota_child sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

* 2SLS

ivreg2 out_of_quota_child (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_ocp_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_ocp_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)


********************************************************************************

gen rich = .
replace rich = 1 if gdppc2000>5.550627 & gdppc2000!=.
replace rich = 0 if gdppc2000<=5.550627 & gdppc2000!=.

gen sib_hus_rich = sib_hus*rich
gen sib_wife_rich = sib_wife*rich
gen sib_total_rich = sib_total*rich

gen exp_llf_hus_rich = exp_llf_hus*rich
gen exp_ocp_hus_rich = exp_ocp_hus*rich
gen exp_llf_wife_rich = exp_llf_wife*rich
gen exp_ocp_wife_rich = exp_ocp_wife*rich


********************************************************************************

** Table 4. Effect of the number of siblings on the number of children by income (2SLS)

est clear

ivreg2 children_wife (sib_hus sib_wife sib_hus_rich sib_wife_rich = exp_llf_hus exp_ocp_hus exp_llf_hus_rich exp_ocp_hus_rich exp_llf_wife exp_ocp_wife exp_llf_wife_rich exp_ocp_wife_rich) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife (sib_total sib_total_rich = exp_llf_hus exp_ocp_hus exp_llf_hus_rich exp_ocp_hus_rich exp_llf_wife exp_ocp_wife exp_llf_wife_rich exp_ocp_wife_rich) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife (sib_hus sib_wife sib_hus_rich sib_wife_rich = exp_llf_hus exp_ocp_hus exp_llf_hus_rich exp_ocp_hus_rich exp_llf_wife exp_ocp_wife exp_llf_wife_rich exp_ocp_wife_rich) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife (sib_total sib_total_rich = exp_llf_hus exp_ocp_hus exp_llf_hus_rich exp_ocp_hus_rich exp_llf_wife exp_ocp_wife exp_llf_wife_rich exp_ocp_wife_rich) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 out_of_quota_child (sib_hus sib_wife sib_hus_rich sib_wife_rich = exp_llf_hus exp_ocp_hus exp_llf_hus_rich exp_ocp_hus_rich exp_llf_wife exp_ocp_wife exp_llf_wife_rich exp_ocp_wife_rich) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child (sib_total sib_total_rich = exp_llf_hus exp_ocp_hus exp_llf_hus_rich exp_ocp_hus_rich exp_llf_wife exp_ocp_wife exp_llf_wife_rich exp_ocp_wife_rich) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child (sib_hus sib_wife sib_hus_rich sib_wife_rich = exp_llf_hus exp_ocp_hus exp_llf_hus_rich exp_ocp_hus_rich exp_llf_wife exp_ocp_wife exp_llf_wife_rich exp_ocp_wife_rich) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child (sib_total sib_total_rich = exp_llf_hus exp_ocp_hus exp_llf_hus_rich exp_ocp_hus_rich exp_llf_wife exp_ocp_wife exp_llf_wife_rich exp_ocp_wife_rich) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_income_2sls_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_rich sib_wife_rich sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_rich sib_wife_rich sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_income_2sls_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_rich sib_wife_rich sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_rich sib_wife_rich sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)


********************************************************************************

** Table A8. Effect of income on the number of children

est clear

ivreg2 children_wife rich iage_hus1-iage_hus75 iage_wife1-iage_wife73 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife rich sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife rich sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

esttab m1 m2 m3 m4 using Table_income_kids_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (rich sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(rich sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m1 m2 m3 m4 using Table_income_kids_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (rich sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(rich sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)


********************************************************************************

** Table A9. Effect of the number of siblings on the number of children by income (OLS)

est clear

ivreg2 children_wife sib_hus sib_wife sib_hus_rich sib_wife_rich iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife sib_total sib_total_rich iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife sib_hus sib_wife sib_hus_rich sib_wife_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife sib_total sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 out_of_quota_child sib_hus sib_wife sib_hus_rich sib_wife_rich iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child sib_total sib_total_rich iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child sib_hus sib_wife sib_hus_rich sib_wife_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child sib_total sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_income_ols_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_rich sib_wife_rich sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_rich sib_wife_rich sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_income_ols_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_rich sib_wife_rich sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_rich sib_wife_rich sib_total_rich yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)


********************************************************************************

gen sib_hus_urban = sib_hus*urban_hukou_12_wife
gen sib_wife_urban = sib_wife*urban_hukou_12_wife
gen sib_total_urban = sib_total*urban_hukou_12_wife

gen exp_llf_hus_urban = exp_llf_hus*urban_hukou_12_wife
gen exp_ocp_hus_urban = exp_ocp_hus*urban_hukou_12_wife
gen exp_llf_wife_urban = exp_llf_wife*urban_hukou_12_wife
gen exp_ocp_wife_urban = exp_ocp_wife*urban_hukou_12_wife


********************************************************************************

** Table 5. Effect of the number of siblings on the number of children by hukou status (2SLS)

est clear

ivreg2 children_wife (sib_hus sib_wife sib_hus_urban sib_wife_urban = exp_llf_hus exp_ocp_hus exp_llf_hus_urban exp_ocp_hus_urban exp_llf_wife exp_ocp_wife exp_llf_wife_urban exp_ocp_wife_urban) urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife (sib_total sib_total_urban = exp_llf_hus exp_ocp_hus exp_llf_hus_urban exp_ocp_hus_urban exp_llf_wife exp_ocp_wife exp_llf_wife_urban exp_ocp_wife_urban) urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife (sib_hus sib_wife sib_hus_urban sib_wife_urban = exp_llf_hus exp_ocp_hus exp_llf_hus_urban exp_ocp_hus_urban exp_llf_wife exp_ocp_wife exp_llf_wife_urban exp_ocp_wife_urban) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife (sib_total sib_total_urban = exp_llf_hus exp_ocp_hus exp_llf_hus_urban exp_ocp_hus_urban exp_llf_wife exp_ocp_wife exp_llf_wife_urban exp_ocp_wife_urban) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 out_of_quota_child (sib_hus sib_wife sib_hus_urban sib_wife_urban = exp_llf_hus exp_ocp_hus exp_llf_hus_urban exp_ocp_hus_urban exp_llf_wife exp_ocp_wife exp_llf_wife_urban exp_ocp_wife_urban) urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child (sib_total sib_total_urban = exp_llf_hus exp_ocp_hus exp_llf_hus_urban exp_ocp_hus_urban exp_llf_wife exp_ocp_wife exp_llf_wife_urban exp_ocp_wife_urban) urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child (sib_hus sib_wife sib_hus_urban sib_wife_urban = exp_llf_hus exp_ocp_hus exp_llf_hus_urban exp_ocp_hus_urban exp_llf_wife exp_ocp_wife exp_llf_wife_urban exp_ocp_wife_urban) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child (sib_total sib_total_urban = exp_llf_hus exp_ocp_hus exp_llf_hus_urban exp_ocp_hus_urban exp_llf_wife exp_ocp_wife exp_llf_wife_urban exp_ocp_wife_urban) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_hukou_2sls_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_urban sib_wife_urban sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_urban sib_wife_urban sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_hukou_2sls_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_urban sib_wife_urban sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_urban sib_wife_urban sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)


********************************************************************************

** Table A10. Effect of the number of siblings on the number of children by hukou status (OLS)

est clear

ivreg2 children_wife sib_hus sib_wife sib_hus_urban sib_wife_urban urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife sib_total sib_total_urban urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife sib_hus sib_wife sib_hus_urban sib_wife_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife sib_total sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 out_of_quota_child sib_hus sib_wife sib_hus_urban sib_wife_urban urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child sib_total sib_total_urban urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child sib_hus sib_wife sib_hus_urban urban_hukou_12_wife sib_wife_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child sib_total sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_hukou_ols_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_urban sib_wife_urban sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_urban sib_wife_urban sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_hukou_ols_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_urban sib_wife_urban sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_urban sib_wife_urban sib_total_urban yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)


********************************************************************************

gen sib_hus_age = sib_hus*(46-age_wife)
gen sib_wife_age = sib_wife*(46-age_wife)
gen sib_total_age = sib_total*(46-age_wife)

gen exp_llf_hus_age = exp_llf_hus*(46-age_wife)
gen exp_ocp_hus_age = exp_ocp_hus*(46-age_wife)
gen exp_llf_wife_age = exp_llf_wife*(46-age_wife)
gen exp_ocp_wife_age = exp_ocp_wife*(46-age_wife)


********************************************************************************

** Table 6. Effect of the number of siblings on the number of children by age (2SLS)

est clear

ivreg2 children_wife (sib_hus sib_wife sib_hus_age sib_wife_age = exp_llf_hus exp_ocp_hus exp_llf_hus_age exp_ocp_hus_age exp_llf_wife exp_ocp_wife exp_llf_wife_age exp_ocp_wife_age) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife (sib_total sib_total_age = exp_llf_hus exp_ocp_hus exp_llf_hus_age exp_ocp_hus_age exp_llf_wife exp_ocp_wife exp_llf_wife_age exp_ocp_wife_age) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife (sib_hus sib_wife sib_hus_age sib_wife_age = exp_llf_hus exp_ocp_hus exp_llf_hus_age exp_ocp_hus_age exp_llf_wife exp_ocp_wife exp_llf_wife_age exp_ocp_wife_age) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife (sib_total sib_total_age = exp_llf_hus exp_ocp_hus exp_llf_hus_age exp_ocp_hus_age exp_llf_wife exp_ocp_wife exp_llf_wife_age exp_ocp_wife_age) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 out_of_quota_child (sib_hus sib_wife sib_hus_age sib_wife_age = exp_llf_hus exp_ocp_hus exp_llf_hus_age exp_ocp_hus_age exp_llf_wife exp_ocp_wife exp_llf_wife_age exp_ocp_wife_age) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child (sib_total sib_total_age = exp_llf_hus exp_ocp_hus exp_llf_hus_age exp_ocp_hus_age exp_llf_wife exp_ocp_wife exp_llf_wife_age exp_ocp_wife_age) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child (sib_hus sib_wife sib_hus_age sib_wife_age = exp_llf_hus exp_ocp_hus exp_llf_hus_age exp_ocp_hus_age exp_llf_wife exp_ocp_wife exp_llf_wife_age exp_ocp_wife_age) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child (sib_total sib_total_age = exp_llf_hus exp_ocp_hus exp_llf_hus_age exp_ocp_hus_age exp_llf_wife exp_ocp_wife exp_llf_wife_age exp_ocp_wife_age) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_age_2sls_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_age sib_wife_age sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_age sib_wife_age sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_age_2sls_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_age sib_wife_age sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_age sib_wife_age sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)


********************************************************************************

** Table A11. Effect of the number of siblings on the number of children by age (OLS)

est clear

ivreg2 children_wife sib_hus sib_wife sib_hus_age sib_wife_age iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife sib_total sib_total_age iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife sib_hus sib_wife sib_hus_age sib_wife_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife sib_total sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 out_of_quota_child sib_hus sib_wife sib_hus_age sib_wife_age iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child sib_total sib_total_age iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child sib_hus sib_wife sib_hus_age sib_wife_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child sib_total sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_age_ols_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_age sib_wife_age sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_age sib_wife_age sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_kids_age_ols_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total sib_hus_age sib_wife_age sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total sib_hus_age sib_wife_age sib_total_age yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)


********************************************************************************

** Table 7. Effect of the number of siblings on the ideal number of children of husband/wife (OLS)

est clear

ivreg2 ideal_children_hus sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 ideal_children_hus sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 ideal_children_hus sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 ideal_children_hus sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 ideal_children_wife sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 ideal_children_wife sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 ideal_children_wife sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 ideal_children_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_ideals_ols_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_ideals_ols_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)


********************************************************************************

** Table A12. Effect of the number of siblings on the ideal number of children of husband/wife (2SLS)

est clear

ivreg2 ideal_children_hus (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 ideal_children_hus (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 ideal_children_hus (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 ideal_children_hus (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 ideal_children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 ideal_children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 ideal_children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 ideal_children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_ideals_2sls_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_ideals_2sls_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)


********************************************************************************

** Table 8. Effect of the ideal number of children of husband/wife on the number of children (OLS)

est clear

ivreg2 children_wife ideal_children_hus ideal_children_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 out_of_quota_child ideal_children_hus ideal_children_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 out_of_quota_child ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

esttab m1 m2 m3 m4 using Table_ideals_kids_v2_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m1 m2 m3 m4 using Table_ideals_kids_v2_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)


********************************************************************************

** Table 9. Effect of the number of siblings and the ideal number of children of husband/wife on the number of children (OLS)

est clear

ivreg2 children_wife sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife sib_hus sib_wife ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife sib_total ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

ivreg2 out_of_quota_child sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child sib_hus sib_wife ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child sib_total ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m8

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_ideals_kids_v2_fw.rtf, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total  ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m1 m2 m3 m4 m5 m6 m7 m8 using Table_sib_ideals_kids_v2_fw.tex, replace b(3) se(3) star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total  ideal_children_hus ideal_children_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)




********************************************************************************

**** Different sample weights


********************************************************************************

** Table A4. Effect of the number of siblings on the number of children (OLS)

* female weights

est clear

ivreg2 children_wife sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30  if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2
 
ivreg2 children_wife sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

ivreg2 children_wife sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

* male weights

ivreg2 children_wife sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 children_wife sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m6
 
ivreg2 children_wife sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 children_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m8

* no weights

ivreg2 children_wife sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m9

ivreg2 children_wife sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m10
 
ivreg2 children_wife sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m11

ivreg2 children_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m12

esttab m3 m4 m7 m8 m11 m12 using Table_sib_kids_weights_ols.rtf, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m3 m4 m7 m8 m11 m12 using Table_sib_kids_weights_ols.tex, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)


********************************************************************************

** Table A5. Effect of the number of siblings on the number of children (2SLS)

* female weights

est clear

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

* male weights

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m8

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m9

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m10

ivreg2 children_wife (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m11

ivreg2 children_wife (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m12

esttab m3 m4 m7 m8 m11 m12 using Table_sib_kids_weights_2sls.rtf, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

esttab m3 m4 m7 m8 m11 m12 using Table_sib_kids_weights_2sls.tex, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)


********************************************************************************

** Table A6. Effect of the number of siblings on violation of the OCP (OLS)

* female weights

est clear

ivreg2 out_of_quota_child sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 out_of_quota_child sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2
 
ivreg2 out_of_quota_child sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 out_of_quota_child sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

* male weights

ivreg2 out_of_quota_child sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m6
 
ivreg2 out_of_quota_child sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m8

* no weights

ivreg2 out_of_quota_child sib_hus sib_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m9

ivreg2 out_of_quota_child sib_total iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m10
 
ivreg2 out_of_quota_child sib_hus sib_wife yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m11

ivreg2 out_of_quota_child sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m12

esttab m3 m4 m7 m8 m11 m12 using Table_sib_viol_weights_ols.rtf, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)

esttab m3 m4 m7 m8 m11 m12 using Table_sib_viol_weights_ols.tex, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean)


********************************************************************************

** Table A7. Effect of the number of siblings on violation of the OCP (2SLS)

* female weights

est clear

ivreg2 out_of_quota_child (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m1

ivreg2 out_of_quota_child (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m2

ivreg2 out_of_quota_child (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m3

ivreg2 out_of_quota_child (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat_wife], cluster(cluster_group)

estadd ysumm

est store m4

* male weights

ivreg2 out_of_quota_child (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m5

ivreg2 out_of_quota_child (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m6

ivreg2 out_of_quota_child (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m7

ivreg2 out_of_quota_child (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1 [pw = rswt_nat], cluster(cluster_group)

estadd ysumm

est store m8

ivreg2 out_of_quota_child (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m9

ivreg2 out_of_quota_child (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m10

ivreg2 out_of_quota_child (sib_hus sib_wife = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m11

ivreg2 out_of_quota_child (sib_total = exp_llf_hus exp_ocp_hus exp_llf_wife exp_ocp_wife) yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife iage_hus1-iage_hus75 iage_wife1-iage_wife73 iprov_12_wife1-iprov_12_wife30 if sample3==1, cluster(cluster_group)

estadd ysumm

est store m12

esttab m3 m4 m7 m8 m11 m12 using Table_sib_viol_weights_2sls.rtf, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

esttab m3 m4 m7 m8 m11 m12 using Table_sib_viol_weights_2sls.tex, replace b(3) se(3) r2 star(* 0.1 ** 0.05 *** 0.01) keep (sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) order(sib_hus sib_wife sib_total yr_school_hus yr_school_wife birth_quota minority urban_hukou_12_wife) label stats(N r2 ymean rkf)

